
// Date and time functions using a DS1302 RTC connected via I2C and Wire lib

#include <Wire.h>
#include "DS1302.h"
#include <LiquidCrystal_I2C.h>
DS1302 rtc(2, 3, 4);
// Init a Time-data structure
Time t;
LiquidCrystal_I2C lcd(0x27,16,2);

byte LT[8] = {B11111,B11111,B11000,B11000,B11000,B11000,B11000,B11000};
byte RT[8] = {B11111,B11111,B00011,B00011,B00011,B00011,B00011,B00011};
byte LN[8] = {B11000,B11000,B11000,B11000,B11000,B11000,B11111,B11111};
byte RN[8] = {B00011,B00011,B00011,B00011,B00011,B00011,B11111,B11111};
byte VV[8] = {B11111,B11111,B00000,B00000,B00000,B00000,B00000,B00000};
byte NN[8] = {B00000,B00000,B00000,B00000,B00000,B00000,B11111,B11111};
byte LL[8] = {B11111,B11111,B11000,B11000,B11000,B11000,B11111,B11111};
byte RR[8] = {B11111,B11111,B00011,B00011,B00011,B00011,B11111,B11111};

void setup () {
  Serial.begin(9600);
  Wire.begin();
  lcd.init();                      // initialize the lcd 
  lcd.backlight();
  lcd.home();

  lcd.createChar(0,LT);
  lcd.createChar(1,RT);
  lcd.createChar(2,LN);
  lcd.createChar(3,RN);
  lcd.createChar(4,VV);
  lcd.createChar(5,NN);
  lcd.createChar(6,LL);
  lcd.createChar(7,RR);
  
  lcd.clear();  // sets the LCD's rows and colums:
}

void loop () {

  digitalClockDisplay();  
  delay(100);

}
void digitalClockDisplay(){
  t = rtc.getTime();// Get data from the DS1302
  lcd.setCursor(0, 0);
  DayOfWeek(t.dow);
  lcd.setCursor(0, 1);  
  lcd.print(t.date);

  printDigits(t.hour/10,2); 
  printDigits(t.hour%10,4); 

  printDigits(t.min/10,7);
  printDigits(t.min%10,9);

  printDigits(t.sec/10,12);
  printDigits(t.sec%10,14);

  lcd.setCursor(6, 0);
  lcd.print(".");
  lcd.setCursor(6, 1);
  lcd.print(".");
  lcd.setCursor(11, 0);
  lcd.print(".");
  lcd.setCursor(11, 1);
  lcd.print(".");
}

void printDigits(int digits, int x){
  switch (digits) {
  case 0:  
    lcd.setCursor(x,0);
    lcd.write(0);lcd.write(1);
    lcd.setCursor(x, 1); 
    lcd.write(2);lcd.write(3);break;
  case 1:  
    lcd.setCursor(x,0);
    lcd.write(1);lcd.print(" ");
    lcd.setCursor(x,1);
    lcd.write(3);lcd.write(5);break;
  case 2:  
    lcd.setCursor(x,0);
    lcd.write(4);lcd.write(7);
    lcd.setCursor(x, 1);
    lcd.write(6);lcd.write(5);break;
  case 3:  
    lcd.setCursor(x,0);
    lcd.write(4);lcd.write(7);
    lcd.setCursor(x, 1);
    lcd.write(5);lcd.write(7);break;
  case 4:  
    lcd.setCursor(x,0);
    lcd.write(2);lcd.write(3);
    lcd.setCursor(x, 1);
    lcd.print(" ");lcd.write(1);break;
  case 5:  
    lcd.setCursor(x,0);
    lcd.write(6);lcd.write(4);
    lcd.setCursor(x, 1);
    lcd.write(5);lcd.write(7);break;
  case 6:  
    lcd.setCursor(x,0);
    lcd.write(0);lcd.write(4);
    lcd.setCursor(x, 1);
    lcd.write(6);lcd.write(7);break;
  case 7:  
    lcd.setCursor(x,0);
    lcd.write(4);lcd.write(1);
    lcd.setCursor(x, 1);
    lcd.print(" ");lcd.write(1);break;
  case 8:  
    lcd.setCursor(x,0);
    lcd.write(6);lcd.write(7);
    lcd.setCursor(x, 1);
    lcd.write(6);lcd.write(7);break;
  case 9:
    lcd.setCursor(x,0);
    lcd.write(6);lcd.write(7);
    lcd.setCursor(x, 1);
    lcd.write(5);lcd.write(3);break;
  }
}

void DayOfWeek(int x) {
  switch (x) {
  case 1:  lcd.print("MN");break;
  case 2:  lcd.print("TS");break;
  case 3:  lcd.print("WD");break;
  case 4:  lcd.print("TH");break;
  case 5:  lcd.print("FD");break;
  case 6:  lcd.print("SD");break;
  case 7:  lcd.print("SU");break;
  }
}
